@@ -3,10 +3,11 @@ import json
 import os
 import requests
 import shutil
+import sys
 from testinlabel.cli import account
 
 import testinlabel
-from testinlabel import TLA
+from testinlabel.TLA import TLA
 
 
 def _download(url, savePath):
@@ -71,6 +72,57 @@ def main(ctx, access_key, secret_key, host, debug):
 
     ctx.obj = _tla
 
+@main.command()
+# @click.option("-k", "--task_key", 'taskKey', default="", required=True, help="the task you wolud like to oprate")
+@click.argument("taskKey")
+@click.pass_context
+def template(ctx, taskKey):
+    """ generate export code template """
+    if ctx.obj == None:
+        account._noLoginMessage()
+    codeContent=f"""from testinlabel.exportAbstract import ExportAbstract # warning: don't edit this line !!!
+from testinlabel.TLA import TLA     # warning: don't edit this line !!!
+
+#import your packages
+
+class Export(ExportAbstract):
+
+    def __init__(self, tla: TLA):       # warning: don't edit this line !!!
+        self.tla = tla                  # warning: don't edit this line !!!
+        self.tla.SetKey("{taskKey}")  # warning: don't edit this line !!!
+        self.tla.GetLabelData()         # warning: don't edit this line !!!
+
+    def exec(self):
+        # edit following code to
+        for item in self.tla.taskList:
+            print(item["imgUrl"])
+"""
+    with open("export.py", "w", encoding="utf-8") as sf:
+        sf.write(codeContent)
+
+    click.echo("script template generate success! script name: export.py")
+    click.echo("use command: tla export export.py to export your data")
+    click.echo("more: tla export --help")
+
+
+@main.command()
+# @click.option("-f", "--script-file", 'file', required=True, default="", help="script file path")
+@click.argument("scprit_path")
+@click.pass_context
+def export(ctx, scprit_path):
+    """ exec export """
+    if ctx.obj == None:
+        account._noLoginMessage()
+    try:
+        sys.path.append(os.path.split(scprit_path)[0])
+        from export import Export
+        ex = Export(ctx.obj)
+        ex.exec()
+    except Exception as e:
+        print(e)
+        raise Exception(f"can't import Export")
+
+    click.echo("done!")
 
 @main.command()
 @click.pass_context
